@@ -22,9 +22,8 @@ from typing import Any, Dict, Optional, Sequence, Union
 
 import pytorch_lightning as pl
 import torch
-from lightning_lite.utilities import rank_zero_info
-from lightning_lite.utilities.distributed import ReduceOp
-from lightning_lite.utilities.enums import _StrategyType
+from lightning_fabric.utilities import rank_zero_info
+from lightning_fabric.utilities.distributed import ReduceOp
 from pytorch_lightning.callbacks import BaseFinetuning
 from pytorch_lightning.strategies.strategy import Strategy
 from pytorch_lightning.trainer.states import TrainerFn
@@ -38,7 +37,9 @@ from finetuning_scheduler.fts_supporters import (
     FTSState,
     ScheduleImplMixin,
     ScheduleParsingMixin,
+    STRATEGY_ADAPTERS,
 )
+from finetuning_scheduler.strategy_adapters.base import StrategyAdapter
 
 log = logging.getLogger(__name__)
 
@@ -86,6 +87,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
        :external+torch:class:`~torch.distributed.optim.ZeroRedundancyOptimizer`, setting ``overlap_with_ddp`` to
        ``True`` is not supported because that optimizer mode only supports a single parameter group.
     """
+    pl_module: pl.LightningModule
+    strategy_adapter: StrategyAdapter
 
     def __init__(
         self,
@@ -96,11 +99,14 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         gen_ft_sched_only: bool = False,
         epoch_transitions_only: bool = False,
         reinit_lr_cfg: Optional[Dict] = None,
+        strategy_adapter_cfg: Optional[Dict] = None,
+        custom_strategy_adapter: Optional[Dict[str, str]] = None,
         allow_untested: bool = False,
         apply_lambdas_new_pgs: bool = False,
+        logging_level: int = logging.INFO,
     ):
         r"""
-        Define and configure a scheduled fine-tuning training session.
+        Arguments used to define and configure a scheduled fine-tuning training session:
 
         Args:
             ft_schedule: The fine-tuning schedule to be executed. Usually will be a .yaml file path but can also be a
@@ -117,8 +123,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 being executed. Defaults to -1.
             base_max_lr: The default maximum learning rate to use for the parameter groups associated with each
                 scheduled fine-tuning depth if not explicitly specified in the fine-tuning schedule. If overridden to
-                ``None``, will be set to the ``lr`` of the first scheduled fine-tuning depth scaled by 1e-1. Defaults to
-                1e-5.
+                ``None``, will be set to the ``lr`` of the first scheduled fine-tuning depth. Defaults to 1e-5.
             restore_best: If ``True``, restore the best available (defined by the
                 :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint`) checkpoint
                 before fine-tuning depth transitions. Defaults to ``True``.
@@ -167,8 +172,11 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                     Most unsupported strategies and schedulers, however, are currently unsupported because they require
                     varying degrees of modification to be compatible.
 
-                    For instance, with respect to strategies, ``deepspeed`` requires an ``add_param_group`` method,
-                    ``tpu_spawn`` an override of the current broadcast method to include python objects.
+                    For instance, with respect to strategies, ``deepspeed`` will require a
+                    :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` similar to the one written for
+                    ``FSDP`` (:class:`~finetuning_scheduler.strategy_adapters.FSDPStrategyAdapter`) to be written before
+                    support can be added (PRs welcome!), while ``tpu_spawn`` would require an override of the current
+                    broadcast method to include python objects.
 
                     Regarding lr schedulers, :external+torch:class:`~torch.optim.lr_scheduler.ChainedScheduler` and
                     :external+torch:class:`~torch.optim.lr_scheduler.SequentialLR` are examples of schedulers not
@@ -176,13 +184,32 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                     introduce. If a supported torch lr scheduler does not meet your requirements, one can always
                     subclass a supported lr scheduler and modify it as required
                     (e.g. :external+torch:class:`~torch.optim.lr_scheduler.LambdaLR` is especially useful for this).
+            strategy_adapter_cfg: A configuration dictionary that will be applied to the
+                :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` associated with the current training
+                :external+pl:class:`~pytorch_lightning.strategies.Strategy`. See the relevant
+                :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` documentation for strategy-specific
+                configuration options. Defaults to None.
+            custom_strategy_adapter: A dictionary associating the canonical ``strategy_name`` of a
+                :external+pl:class:`~pytorch_lightning.strategies.Strategy` (potentially a custom user-registered one)
+                to the fully qualified path of a
+                :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` subclass. This is an experimental
+                feature that is subject to change. Requires ``allow_untested`` to be set to ``True``. Defaults to None.
             apply_lambdas_new_pgs: If ``True``, applies most recent lambda in ``lr_lambdas`` list to newly added
                 optimizer groups for lr schedulers that have a ``lr_lambdas`` attribute. Note this option only applies
                 to phases without reinitialized lr schedulers. Phases with defined lr scheduler reinitialization configs
                 will always apply the specified lambdas. Defaults to ``False``.
+            logging_level: Sets the logging level for :class:`~finetuning_scheduler.fts.FinetuningScheduler`. Defaults
+                to ``INFO``.
 
         Attributes:
             _fts_state: The internal :class:`~finetuning_scheduler.fts.FinetuningScheduler` state.
+            strategy_adapter_cfg: A configuration dictionary that will be applied to the
+                :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` associated with the current training
+                :external+pl:class:`~pytorch_lightning.strategies.Strategy`.
+            epoch_transitions_only: Whether to use epoch-driven stopping criteria exclusively.
+            base_max_lr: The default maximum learning rate to use for the parameter groups associated with each
+                scheduled fine-tuning depth if not explicitly specified in the fine-tuning schedule. If overridden to
+                ``None``, will be set to the ``lr`` of the first scheduled fine-tuning depth. Defaults to 1e-5.
         """
         super().__init__()
         self._fts_state = FTSState()
@@ -193,9 +220,12 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         self.gen_ft_sched_only = gen_ft_sched_only
         self.epoch_transitions_only = epoch_transitions_only
         self.reinit_lr_cfg = reinit_lr_cfg
+        self.strategy_adapter_cfg = strategy_adapter_cfg or {}
+        self.custom_strategy_adapter = custom_strategy_adapter
         self.allow_untested = allow_untested
         self.apply_lambdas_new_pgs = apply_lambdas_new_pgs
-        self.pl_module: pl.LightningModule
+        rz_logger = logging.getLogger("pytorch_lightning.utilities.rank_zero")
+        rz_logger.setLevel(logging_level)
 
     @property
     def curr_depth(self) -> int:
@@ -216,16 +246,21 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         return max(self.max_depth - self._fts_state._curr_depth, 0)
 
     @staticmethod
-    def _supported_strategy_types() -> Sequence[Union[_StrategyType, str]]:
+    def _supported_strategy_types() -> Sequence[str]:
         return (
-            _StrategyType.DP,
-            _StrategyType.DDP,
-            _StrategyType.DDP_FORK,
-            _StrategyType.DDP_SPAWN,
-            # _StrategyType.DEEPSPEED,  # support to be re-evaluated if add optimizer pg functionality added to DS API
-            _StrategyType.DDP_SHARDED,
-            _StrategyType.DDP_SHARDED_SPAWN,
+            "dp",
+            "ddp",
+            "ddp_find_unused_parameters_false",
+            "ddp_spawn",
+            "ddp_fork",
+            "ddp_notebook",
             "single_device",
+            # TODO: `native` suffix will be removed from `fsdp` strategies in 2.0
+            "fsdp_native",
+            "fsdp_native_full_shard_offload",
+            "ddp_sharded",  # TODO: remove in 2.0
+            "ddp_sharded_spawn"  # TODO: remove in 2.0,
+            # "deepspeed",  # relevant FTS strategy adapter not yet available, PRs welcome!
         )
 
     def freeze_before_training(self, pl_module: "pl.LightningModule") -> None:
@@ -242,8 +277,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         """Prepare and execute the next scheduled fine-tuning level
         1. Restore the current best model checkpoint if appropriate
         2. Thaw model parameters according the the defined schedule
-        3. Synchronize the states of :external+pl:class:`~pytorch_lightning.loops.FitLoop` and
-        :attr:`~finetuning_scheduler.fts.FinetuningScheduler._fts_state`
+        3. Synchronize the states of ``FitLoop`` and :attr:`~finetuning_scheduler.fts.FinetuningScheduler._fts_state`
 
         .. note::
 
@@ -279,8 +313,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.current_depth`
 
         Args:
-            optimizer (:class:`~torch.optim.Optimizer`): The :class:`~torch.optim.Optimizer` to which parameter groups
-                will be configured and added.
+            optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
+                :external+torch:class:`~torch.optim.Optimizer` to which parameter groups will be configured and added.
             depth: The maximum index of the fine-tuning schedule for which to configure the optimizer parameter
                 groups.
             depth_sync: If ``True``, configure optimizer parameter groups for all depth indices greater
@@ -295,9 +329,11 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             thaw_layers = {d: l for d, l in self.ft_schedule.items() if d > self._fts_state._best_ckpt_depth}.items()
         else:
             thaw_layers = {depth: self.ft_schedule[depth]}.items()
-        for i, next_tl in thaw_layers:
+        for i, orig_next_tl in thaw_layers:
+            next_tl = deepcopy(orig_next_tl)
+            next_tl["params"] = self.strategy_adapter.fts_optim_view(next_tl["params"])
             if i <= depth:
-                _, self._fts_state._curr_thawed_params = FinetuningScheduler.exec_ft_phase(
+                _, self._fts_state._curr_thawed_params = self.strategy_adapter.exec_ft_phase(
                     self.pl_module, thaw_pl=next_tl["params"]
                 )
                 FinetuningScheduler.add_optimizer_groups(
@@ -314,19 +350,20 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                         new_lr_scheduler=new_scheduler_cfg, trainer=self.pl_module.trainer, optimizer=optimizer
                     )
                 else:
-                    for config in self.pl_module.trainer.lr_scheduler_configs:
-                        show_warn_lambdas = (
-                            hasattr(config.scheduler, "lr_lambdas")
-                            and config.scheduler.lr_lambdas[-1] is not None  # type: ignore[union-attr]
-                            and not self.apply_lambdas_new_pgs
-                        )
-                        if show_warn_lambdas:
-                            rank_zero_warn(
-                                "The lr scheduler used in this phase has lr_lambdas but will use a "
-                                "configured lr for new parameter groups because `apply_lambdas_new_pgs` is "
-                                "set to the default of `False`. If you would like new groups to have lr "
-                                "lambdas applied, set `apply_lambdas_new_pgs` to `True`."
+                    if self.pl_module.trainer.lr_scheduler_configs:
+                        for config in self.pl_module.trainer.lr_scheduler_configs:
+                            show_warn_lambdas = (
+                                hasattr(config.scheduler, "lr_lambdas")
+                                and config.scheduler.lr_lambdas[-1] is not None  # type: ignore[union-attr]
+                                and not self.apply_lambdas_new_pgs
                             )
+                            if show_warn_lambdas:
+                                rank_zero_warn(
+                                    "The lr scheduler used in this phase has lr_lambdas but will use a "
+                                    "configured lr for new parameter groups because `apply_lambdas_new_pgs` is "
+                                    "set to the default of `False`. If you would like new groups to have lr "
+                                    "lambdas applied, set `apply_lambdas_new_pgs` to `True`."
+                                )
 
     def restore_best_ckpt(self) -> None:
         """Restore the current best model checkpoint, according to
@@ -379,6 +416,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         assert self.pl_module.trainer.state.fn is not None
         if self.pl_module.trainer.state.fn == TrainerFn.FITTING:
             try:
+                # enable strategy adapters to restore optimizer if `Strategy.lightning_restore_optimizer` is overridden
+                self.strategy_adapter.on_before_restore_optimizers_and_lrs()
                 # restore optimizers and schedulers state
                 checkpoint_connector.restore_optimizers_and_schedulers()
             except KeyError:
@@ -430,6 +469,46 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             rank_zero_warn(warn_msg)
             early_stopping_callback._transition_es_phase()
 
+    def _strategy_setup(self, trainer: "pl.Trainer") -> None:
+        """Validate a compatible :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy is being used
+        and connects the relevant :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter`.
+
+        Args:
+            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
+                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+
+        Raises:
+            MisconfigurationException: If the
+                :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy being used is not currently
+                compatible with the :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback.
+        """
+        strategy = trainer.strategy
+        supported = [t.lower() for t in self._supported_strategy_types()]
+        if strategy.strategy_name and strategy.strategy_name not in supported:  # type: ignore[attr-defined]
+            if not self.allow_untested:
+                raise MisconfigurationException(
+                    "FTS is has not yet been adapted for or rigorously tested using the specified distributed strategy."
+                    f" Please select from currently compatible distributed strategies ({supported}) or if you would"
+                    " like to attempt to use the currently specified strategy, pass ``allow_untested=True`` to the"
+                    " FinetuningScheduler callback when adding it."
+                )
+            else:
+                warn_msg = (
+                    "Allowing untested strategy"
+                    f" '{strategy.strategy_name}' because ``allow_untested`` is ``True``."  # type: ignore[attr-defined]
+                )
+                rank_zero_warn(warn_msg)
+        if self.custom_strategy_adapter:
+            strategy_cls = self._import_strategy_adapter(strategy.strategy_name, self.custom_strategy_adapter)
+            rank_zero_info(
+                f"Imported custom strategy adapter class type `{strategy_cls}` associated with the current strategy"
+                f" `{strategy.strategy_name}`."
+            )
+        else:
+            strategy_cls = STRATEGY_ADAPTERS.get(strategy.strategy_name, StrategyAdapter)
+        self.strategy_adapter = strategy_cls(**self.strategy_adapter_cfg)
+        self.strategy_adapter.connect(self)
+
     def setup(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", stage: str) -> None:
         """Validate a compatible :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy is being used and
         ensure all :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback dependencies are met. If a valid
@@ -450,50 +529,24 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
 
         Raises:
             SystemExit: Gracefully exit before training if only generating and not executing a fine-tuning schedule.
-            MisconfigurationException: If the
-                :external+pl:class:`~pytorch_lightning.strategies.Strategy` strategy being used is not currently
-                compatible with the :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback.
         """
-        trainer.callbacks, added_es_fts, added_ckpt_fts = self._configure_callback_deps(trainer)
-        strategy = trainer.strategy
-        # if we added callbacks for the user after the setup hooks loop was initiated from trainer, we'll need to
-        # explicitly call the setup hooks for those added callbacks
-        if added_ckpt_fts:
-            trainer.checkpoint_callback.setup(trainer, pl_module, stage)  # type: ignore[union-attr]
-        if added_es_fts:
-            trainer.early_stopping_callback.setup(trainer, pl_module, stage)  # type: ignore[union-attr]
-        assert pl_module is not None and pl_module.trainer is not None
-        supported = [t.lower() for t in self._supported_strategy_types()]
-        if strategy.strategy_name and strategy.strategy_name not in supported:  # type: ignore[attr-defined]
-            if not self.allow_untested:
-                raise MisconfigurationException(
-                    "FTS is has not yet been adapted for or rigorously tested using the specified distributed strategy."
-                    f" Please select from currently compatible distributed strategies ({supported}) or if you would"
-                    " like to attempt to use the currently specified strategy, pass ``allow_untested=True`` to the"
-                    " FinetuningScheduler callback when adding it."
-                )
-            else:
-                warn_msg = (
-                    "Allowing untested strategy"
-                    f" '{strategy.strategy_name}' because ``allow_untested`` is ``True``."  # type: ignore[attr-defined]
-                )
-                rank_zero_warn(warn_msg)
+        self._callback_dep_setup(trainer, pl_module, stage)
+        self._strategy_setup(trainer)
         if self.gen_ft_sched_only:
             if trainer.is_global_zero:
                 assert trainer.log_dir is not None
                 _ = self.gen_ft_schedule(pl_module, trainer.log_dir)
                 log.info("Bypassing training, generating fine-tuning schedule for review and subsequent fine-tuning")
             raise SystemExit()
-        else:
-            if not self.epoch_transitions_only:
-                assert isinstance(trainer.early_stopping_callback, FTSEarlyStopping)
-                trainer.early_stopping_callback.final_phase = False
-                trainer.early_stopping_callback.es_phase_complete = False
-            self._fts_state._ft_sync_objects = pl_module.trainer.fit_loop, self._fts_state
-            if trainer.ckpt_path:
-                self._fts_state._resume_fit_from_ckpt = True
-            self.freeze_before_training(pl_module)
-            self.pl_module = pl_module  # save pl_module ref for downstream configuration convenience
+        if not self.epoch_transitions_only:
+            assert isinstance(trainer.early_stopping_callback, FTSEarlyStopping)
+            trainer.early_stopping_callback.final_phase = False
+            trainer.early_stopping_callback.es_phase_complete = False
+        self._fts_state._ft_sync_objects = pl_module.trainer.fit_loop, self._fts_state
+        if trainer.ckpt_path:
+            self._fts_state._resume_fit_from_ckpt = True
+        self.freeze_before_training(pl_module)
+        self.pl_module = pl_module  # save pl_module ref for downstream configuration convenience
         self.init_fts()
 
     def on_fit_start(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule") -> None:
@@ -509,6 +562,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
         Raises:
             MisconfigurationException: If more than 1 optimizers are configured indicates a configuration error
         """
+        self.strategy_adapter.on_before_fts_fit_start()
         if len(trainer.optimizers) > 1:
             raise MisconfigurationException("FTS currently only supports a single-optimizer configuration")
         if getattr(trainer.optimizers[0], "_overlap_with_ddp", False):
@@ -521,7 +575,7 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             self._is_supported_lr(type(trainer.lr_scheduler_configs[0].scheduler))
         if self.curr_depth == 0:
             assert isinstance(self.ft_schedule, Dict)
-            self._validate_opt_init(trainer.optimizers[0], self.ft_schedule)
+            self._validate_opt_init()
         super().on_fit_start(trainer, pl_module)
 
     def state_dict(self) -> Dict[str, Any]:
@@ -627,7 +681,9 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
             self._fts_state._curr_depth += 1  # increment depth
             self.step()
             rank_zero_debug(
-                f"Current parameters thawed by the Fine-Tuning Scheduler: {self._fts_state._curr_thawed_params}. "
+                f"Current logical parameters thawed by Fine-Tuning Scheduler: "
+                f"{self.strategy_adapter.logical_param_translation(self._fts_state._curr_thawed_params)}."
+                f"Current actual parameters thawed by Fine-Tuning Scheduler: {self._fts_state._curr_thawed_params}. "
                 f"Current depth is {self.curr_depth}."
             )
             if not self.epoch_transitions_only:
@@ -655,8 +711,8 @@ class FinetuningScheduler(ScheduleImplMixin, ScheduleParsingMixin, CallbackDepMi
                 :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
             pl_module  (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
                 :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
-            optimizer (:class:`~torch.optim.Optimizer`): The :class:`~torch.optim.Optimizer` to which parameter groups
-                will be configured and added.
+            optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
+                :external+torch:class:`~torch.optim.Optimizer` to which parameter groups will be configured and added.
         """
         self._fts_state._ft_global_steps += 1
 
