@@ -33,28 +33,32 @@ from typing import Any, Callable, Dict, List, Optional, Tuple, Type, Union
 import pytorch_lightning as pl
 import torch
 import yaml
-from lightning_lite.utilities import rank_zero_info, rank_zero_only, rank_zero_warn
-from lightning_lite.utilities.cloud_io import get_filesystem
-from lightning_lite.utilities.distributed import _distributed_available
+from lightning_fabric.utilities import rank_zero_info, rank_zero_only, rank_zero_warn
+from lightning_fabric.utilities.cloud_io import get_filesystem
+from lightning_fabric.utilities.distributed import _distributed_available
+from lightning_fabric.utilities.types import _TORCH_LRSCHEDULER, ReduceLROnPlateau
 from pytorch_lightning.callbacks import Callback
 from pytorch_lightning.callbacks.early_stopping import EarlyStopping
 from pytorch_lightning.callbacks.lr_monitor import LearningRateMonitor
 from pytorch_lightning.callbacks.model_checkpoint import ModelCheckpoint
 from pytorch_lightning.core.optimizer import _MockOptimizer
 from pytorch_lightning.trainer.states import TrainerFn
+from pytorch_lightning.utilities import find_shared_parameters
 from pytorch_lightning.utilities.exceptions import MisconfigurationException
-from pytorch_lightning.utilities.imports import _TORCH_GREATER_EQUAL_1_10
 from pytorch_lightning.utilities.rank_zero import rank_zero_debug
 from pytorch_lightning.utilities.types import LRSchedulerConfig
 from torch import Tensor
 from torch.nn import Module
 from torch.optim.optimizer import Optimizer
 
+from finetuning_scheduler.strategy_adapters.fsdp import FSDPStrategyAdapter, StrategyAdapter
+
 log = logging.getLogger(__name__)
 
 CALLBACK_DEP_PARENTS = {"ModelCheckpoint": ModelCheckpoint, "EarlyStopping": EarlyStopping}
 CALLBACK_ATTRS = ("ft_schedule", "max_depth")
 TARGET_CALLBACK_REF = "FinetuningScheduler"
+STRATEGY_ADAPTERS = {"fsdp_native": FSDPStrategyAdapter}
 
 
 @dataclass
@@ -93,11 +97,11 @@ supported_lrs = [
     "CosineAnnealingLR",
     "ReduceLROnPlateau",
     "CosineAnnealingWarmRestarts",
+    "ConstantLR",
+    "LinearLR",
 ]
-if _TORCH_GREATER_EQUAL_1_10:
-    supported_lrs.extend(["ConstantLR", "LinearLR"])
 FTSLRSchedulerTypeTuple = tuple(getattr(torch.optim.lr_scheduler, lr_class) for lr_class in supported_lrs)
-FTSLRSchedulerType = Union[Type[pl.utilities.types._LRScheduler], Type[pl.utilities.types.ReduceLROnPlateau]]
+FTSLRSchedulerType = Union[Type[_TORCH_LRSCHEDULER], Type[ReduceLROnPlateau]]
 
 
 class CallbackResolverMixin(ABC):
@@ -114,8 +118,8 @@ class CallbackResolverMixin(ABC):
         target_callback_ref: str = TARGET_CALLBACK_REF,
         support_multiple_targets: bool = False,
     ) -> None:
-        """Initialize the user-provided callback depedency resolver in accordance with the user-provided module
-        configuration.
+        """Arguments used to initialize the user-provided callback depedency resolver in accordance with the user-
+        provided module configuration:
 
         Args:
             callback_attrs (Tuple, optional): Attribute signature of user-provided callback to be structurally detected
@@ -183,10 +187,10 @@ class FTSEarlyStopping(EarlyStopping, CallbackResolverMixin):
     used if a :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback is detected
     and :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.epoch_transitions_only` is ``False``
 
-    .. warning::
+    .. note::
 
-       :class:`~finetuning_scheduler.fts_supporters.FTSEarlyStopping` is in beta and subject to change. For detailed
-       usage information, see :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`.
+       For detailed usage information,
+       see :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`.
 
     .. note::
 
@@ -347,9 +351,9 @@ class FTSCheckpoint(ModelCheckpoint, CallbackResolverMixin):
     :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint` will automatically be used if a
     :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback is detected.
 
-    .. warning::
-        :class:`~finetuning_scheduler.fts_supporters.FTSCheckpoint` is in beta and subject to change. For detailed usage
-        information, see :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint`.
+    .. note::
+        For detailed usage information, see
+        :external+pl:class:`~pytorch_lightning.callbacks.model_checkpoint.ModelCheckpoint`.
 
     .. note::
 
@@ -522,9 +526,11 @@ class ScheduleParsingMixin(ABC):
         self._validate_schedule_keys()
         self._validate_lr_scheduler_cfg()
         named_params = dict(self.pl_module.named_parameters()).keys()
+        model_shared_params = find_shared_parameters(self.pl_module)
+        msp_ref = tuple((model_shared_params, set(itertools.chain(*model_shared_params))))
         for depth in self.ft_schedule.keys():  # type: ignore[union-attr]
             max_phase = max(max_phase, depth)
-            self._parse_phase(depth, named_params)
+            self._parse_phase(depth, named_params, msp_ref)
             if depth > 0:
                 assert isinstance(self.ft_schedule, Dict)
                 curr_max_epoch = self.ft_schedule[depth]["max_transition_epoch"]
@@ -796,12 +802,16 @@ class ScheduleParsingMixin(ABC):
                 )
                 del self.ft_schedule[depth]["lr"]
 
-    def _parse_phase(self, depth: int, named_params: KeysView) -> None:
-        """Expand any regex expressions specified in an ft_schedule phase to fully qualified parameter names.
+    def _parse_phase(self, depth: int, named_params: KeysView, shared_params: Tuple) -> None:
+        """Expand any regex expressions specified in an ft_schedule phase to fully qualified parameter names. If
+        any shared parameter copies are explicitly specified in the schedule, the copies will be pruned from the
+        schedule with a warning.
 
         Args:
             depth (int): Schedule depth/phase to parse
             named_params (KeysView): The named parameters of the model
+            shared_params (Tuple): A tuple containing the shared parameter names of the current model in both
+                associative list and set forms.
 
         Raises:
             MisconfigurationException: If a specified parameter or regex does not resolve to at least one parameter.
@@ -822,11 +832,19 @@ class ScheduleParsingMixin(ABC):
                 regex_params = [n for n in named_params if ppat.match(n)]
                 resolved_params.extend(regex_params)
             if not (regex_params or explicit_params):
-                raise MisconfigurationException(
-                    f"The parameter or regex '{p}' specified in phase {depth} of the "
-                    "provided explicit schedule did not match any named parameter in the "
-                    "model."
-                )
+                if p in shared_params[1]:
+                    pruning_param_msg = (
+                        f"Pruning explicitly specified shared parameter {p} from provided schedule (it will be thawed "
+                        f" when its registered source parameter {[pl[0] for pl in shared_params[0] if p in pl][0]} is"
+                        " thawed."
+                    )
+                    rank_zero_warn(pruning_param_msg)
+                else:
+                    raise MisconfigurationException(
+                        f"The parameter or regex '{p}' specified in phase {depth} of the "
+                        "provided explicit schedule did not match any named parameter in the "
+                        "model."
+                    )
         self.ft_schedule[depth]["params"] = resolved_params
 
     def _validate_phases_disjoint(self) -> None:
@@ -854,8 +872,8 @@ class ScheduleParsingMixin(ABC):
         Args:
             new_lr_scheduler (Dict): A dictionary defining the new lr scheduler configuration to be initialized.
             trainer (pl.Trainer): The :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object.
-            optimizer (class:`~torch.optim.Optimizer`): The :class:`~torch.optim.Optimizer` around which the new lr
-                scheduler will be wrapped.
+            optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
+                :external+torch:class:`~torch.optim.Optimizer` around which the new lr scheduler will be wrapped.
         """
         lr_scheduler_init = new_lr_scheduler["lr_scheduler_init"]
         lrs_class = self._import_lr_scheduler(lr_scheduler_init)
@@ -954,6 +972,41 @@ class ScheduleParsingMixin(ABC):
             raise MisconfigurationException(error_msg)
         return lrs_class
 
+    @staticmethod
+    def _import_strategy_adapter(strategy_key: str, adapter_map: Dict[str, str]) -> Type[StrategyAdapter]:
+        """Import the custom strategy adapter specified in the ``custom_strategy_adapter`` configuration.
+
+        Args:
+            qualname (Dict): The user-provided custom strategy adapter fully qualified class name.
+
+        Raises:
+            MisconfigurationException: If the specified custom strategy adapter cannot be imported successfully.
+            MisconfigurationException: If the specified `strategy_key` does not match the current strategy.
+
+        Returns:
+            StrategyAdapter: The custom strategy adapter class to be instantiated.
+        """
+        try:
+            qualname = adapter_map.get(strategy_key, None)
+            if not qualname:
+                raise MisconfigurationException(
+                    f"Current strategy name ({strategy_key}) does not map to a custom strategy adapter in the"
+                    f" provided `custom_strategy_adapter` mapping ({adapter_map})."
+                )
+            class_module, class_name = qualname.rsplit(".", 1)
+            module = __import__(class_module, fromlist=[class_name])
+            custom_strategy_adapter_cls = getattr(module, class_name)
+            issubclass(custom_strategy_adapter_cls, StrategyAdapter)
+        except (ImportError, AttributeError) as err:
+            error_msg = (
+                "Could not import the specified custom strategy adapter class using the provided fully qualified class"
+                f" name ({qualname}). Recieved the following error while importing: {err}. Please validate specified"
+                " path."
+            )
+            rank_zero_warn(error_msg)
+            raise MisconfigurationException(error_msg)
+        return custom_strategy_adapter_cls
+
     def _lr_scheduler_sanity_chk(self, lr_scheduler_init: Dict, is_implicit_mode: bool = False) -> None:
         """Before beginning execution of defined fine-tuning schedule, perform a sanity check of the specified lr
         scheduler reinitialization configuration. To the extent reasonable (i.e. without simulating the entire
@@ -1020,15 +1073,18 @@ class ScheduleImplMixin(ABC):
         pass
 
     def init_fts(self) -> None:
-        """Initializes the fine-tuning schedule and prepares the first scheduled level
+        """Initializes the fine-tuning schedule and prepares the first scheduled level.
+
+        Calls the relevant
+        :class:`~finetuning_scheduler.strategy_adapters.StrategyAdapter` hooks before and after fine-tuning schedule
+        initialization.
         1. Generate the default fine-tuning schedule and/or load it into
         :paramref:`~finetuning_scheduler.fts.FinetuningScheduler.ft_schedule`.
-        2. Prepare the first scheduled fine-tuning level, unfreezing the relevant parameters."""
+        2. Prepare the first scheduled fine-tuning level, unfreezing the relevant parameters.
+        """
+        self.strategy_adapter.on_before_init_fts()
         self.init_ft_sched()
-        assert isinstance(self.ft_schedule, Dict)
-        _, self._fts_state._curr_thawed_params = self.exec_ft_phase(
-            self.pl_module, thaw_pl=self.ft_schedule[0]["params"], init_thaw=True
-        )
+        self.strategy_adapter.on_after_init_fts()
 
     def gen_or_load_sched(self) -> None:
         """Load an explicitly specified fine-tuning schedule if one provided, otherwise generate a default one."""
@@ -1208,7 +1264,9 @@ class ScheduleImplMixin(ABC):
         depth = depth or self.curr_depth
         for i, next_tl in self.ft_schedule.items():  # type: ignore[union-attr]
             if i <= depth:
-                _, self._fts_state._curr_thawed_params = self.exec_ft_phase(self.pl_module, thaw_pl=next_tl["params"])
+                _, self._fts_state._curr_thawed_params = self.strategy_adapter.exec_ft_phase(
+                    self.pl_module, thaw_pl=self.strategy_adapter.fts_optim_view(next_tl["params"])
+                )
 
     @staticmethod
     def add_optimizer_groups(
@@ -1225,65 +1283,96 @@ class ScheduleImplMixin(ABC):
         Args:
             module (:class:`~torch.nn.Module`): The :class:`~torch.nn.Module` from which the target optimizer parameters
                 will be read.
-            optimizer (:class:`~torch.optim.Optimizer`): The :class:`~torch.optim.Optimizer` to which parameter groups
-                will be configured and added.
+            optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
+                :external+torch:class:`~torch.optim.Optimizer` to which parameter groups will be configured and added.
             thawed_pl: The list of thawed/unfrozen parameters that should be added to the new parameter group(s)
             no_decay: A list of parameters that should always have weight_decay set to 0. e.g.:
                 ["bias", "LayerNorm.weight"]. Defaults to ``None``.
             lr: The initial learning rate for the new parameter group(s). If not specified,
                 the ``lr`` of the first scheduled fine-tuning depth will be used. Defaults to ``None``.
             apply_lambdas: Whether to apply lr lambdas to newly added groups. Defaults to False.
+
+        .. note::
+
+            If one relies upon the default FTS schedule, the lr provided to this method will be
+            :attr:`~finetuning_scheduler.fts.FinetuningScheduler.base_max_lr` which defaults to ``1e-05``.
         """
         if len(thawed_pl) == 0:
             rank_zero_warn("No thawed parameters passed so no new optimizer groups will be added.")
         else:
             phase_lr = optimizer.param_groups[0]["lr"] if lr is None else float(lr)
             orig_lr_factor = phase_lr
-            for config in module.trainer.lr_scheduler_configs:  # type: ignore[union-attr]
-                scheduler = config.scheduler
-                if hasattr(scheduler, "lr_lambdas") and scheduler.lr_lambdas and apply_lambdas:
-                    phase_lr = phase_lr * scheduler.lr_lambdas[-1](scheduler.last_epoch)
-                added_pgs = 0
-                if no_decay:
-                    optimizer.add_param_group(
-                        {
-                            "params": [
-                                p
-                                for n, p in module.named_parameters()
-                                if not any(nd in n for nd in no_decay) and n in thawed_pl and p.requires_grad
-                            ],
-                            "lr": phase_lr,
-                            "initial_lr": phase_lr,
-                        }
-                    )
-                    optimizer.add_param_group(
-                        {
-                            "params": [
-                                p
-                                for n, p in module.named_parameters()
-                                if any(nd in n for nd in no_decay) and n in thawed_pl and p.requires_grad
-                            ],
-                            "weight_decay": 0.0,
-                            "lr": phase_lr,
-                            "initial_lr": phase_lr,
-                        }
-                    )
-                    added_pgs = 2
-                else:
-                    optimizer.add_param_group(
-                        {
-                            "params": [p for n, p in module.named_parameters() if n in thawed_pl and p.requires_grad],
-                            "lr": phase_lr,
-                            "initial_lr": phase_lr,
-                        }
-                    )
-                    added_pgs = 1
-                if isinstance(scheduler, torch.optim.lr_scheduler.ReduceLROnPlateau):
-                    scheduler.min_lrs.extend([scheduler.min_lrs[0]] * added_pgs)  # type: ignore[attr-defined]
-                else:
-                    scheduler.base_lrs.extend([orig_lr_factor] * added_pgs)
-                    if hasattr(scheduler, "lr_lambdas"):
-                        scheduler.lr_lambdas.extend([scheduler.lr_lambdas[-1]] * added_pgs)
+            if module.trainer.lr_scheduler_configs:  # type: ignore[union-attr]
+                for config in module.trainer.lr_scheduler_configs:  # type: ignore[union-attr]
+                    scheduler = config.scheduler
+                    if hasattr(scheduler, "lr_lambdas") and scheduler.lr_lambdas and apply_lambdas:
+                        phase_lr = phase_lr * scheduler.lr_lambdas[-1](scheduler.last_epoch)
+                    added_pgs = 0
+                    added_pgs = ScheduleImplMixin._add_groups(no_decay, optimizer, module, thawed_pl, phase_lr)
+                    if isinstance(scheduler, torch.optim.lr_scheduler.ReduceLROnPlateau):
+                        scheduler.min_lrs.extend([scheduler.min_lrs[0]] * added_pgs)  # type: ignore[attr-defined]
+                    else:
+                        scheduler.base_lrs.extend([orig_lr_factor] * added_pgs)
+                        if hasattr(scheduler, "lr_lambdas"):
+                            scheduler.lr_lambdas.extend([scheduler.lr_lambdas[-1]] * added_pgs)
+            else:
+                _ = ScheduleImplMixin._add_groups(no_decay, optimizer, module, thawed_pl, phase_lr)
+
+    @staticmethod
+    def _add_groups(
+        no_decay: Optional[list], optimizer: Optimizer, module: Module, thawed_pl: List, phase_lr: float
+    ) -> int:
+        """The actual addition of optimizer groups is done here, separated from ``add_optimizer_groups`` to
+        accommodate corner cases where FTS is being used without an lr scheduler configuration.
+
+        Args:
+            no_decay: A list of parameters that should always have weight_decay set to 0. e.g.:
+                ["bias", "LayerNorm.weight"]. Defaults to ``None``.
+            optimizer (:external+torch:class:`~torch.optim.Optimizer`): The
+                :external+torch:class:`~torch.optim.Optimizer` to which parameter groups will be configured and added.
+            module (:class:`~torch.nn.Module`): The :class:`~torch.nn.Module` from which the target optimizer parameters
+                will be read.
+            thawed_pl: The list of thawed/unfrozen parameters that should be added to the new parameter group(s)
+            phase_lr (float): The initial learning rate for the new parameter group(s).
+
+        Returns:
+            int: The number of optimizer parameter groups that were added.
+        """
+        if no_decay:
+            optimizer.add_param_group(
+                {
+                    "params": [
+                        p
+                        for n, p in module.named_parameters()
+                        if not any(nd in n for nd in no_decay) and n in thawed_pl and p.requires_grad
+                    ],
+                    "lr": phase_lr,
+                    "initial_lr": phase_lr,
+                }
+            )
+            optimizer.add_param_group(
+                {
+                    "params": [
+                        p
+                        for n, p in module.named_parameters()
+                        if any(nd in n for nd in no_decay) and n in thawed_pl and p.requires_grad
+                    ],
+                    "weight_decay": 0.0,
+                    "lr": phase_lr,
+                    "initial_lr": phase_lr,
+                }
+            )
+            added_pgs = 2
+        else:
+            optimizer.add_param_group(
+                {
+                    "params": [p for n, p in module.named_parameters() if n in thawed_pl and p.requires_grad],
+                    "lr": phase_lr,
+                    "initial_lr": phase_lr,
+                }
+            )
+            added_pgs = 1
+        return added_pgs
 
     @staticmethod
     def sync(objs: Tuple, asets: Tuple, agg_func: Callable = max) -> None:
@@ -1299,40 +1388,23 @@ class ScheduleImplMixin(ABC):
             for o, a in zip(objs, attrs):
                 setattr(o, a, agg)
 
-    @staticmethod
-    def exec_ft_phase(module: Module, thaw_pl: List, init_thaw: bool = False) -> Tuple[List, List]:
-        """Thaw/unfreeze the provided list of parameters in the provided :class:`~torch.nn.Module`
-
-        Args:
-            module (:class:`~torch.nn.Module`): The :class:`~torch.nn.Module` that will have parameters selectively
-                unfrozen/thawed.
-            thaw_pl: The list of parameters that should be thawed/unfrozen in the :class:`~torch.nn.Module`
-            init_thaw: If ``True``, modifies message to user accordingly. Defaults to ``False``.
+    def _inspect_fts_opt_state(self) -> Tuple:
+        """Distills relevant initialized optimizer state for validation prior to fit start.
 
         Returns:
-            Tuple[List, List]: A Tuple of two lists.
-                1. The list of newly thawed/unfrozen parameters thawed by this function
-                2. A list of all currently thawed/unfrozen parameters in the target :class:`~torch.nn.Module`
+            Tuple: Distilled optimizer state to be validated.
         """
-        thawed_p_names = []
-        curr_thawed = []
-        for n, p in module.named_parameters():
-            if not p.requires_grad and n in thaw_pl:
-                p.requires_grad = True
-                thawed_p_names.append(n)
-            elif p.requires_grad:
-                curr_thawed.append(n)
-        if thawed_p_names:
-            rank_zero_debug(
-                f"{'Initializing with' if init_thaw else 'Thawed'} the following module parameters: "
-                f"{[n for n in thawed_p_names]}"
-            )
-        curr_thawed.extend(thawed_p_names)
-        rank_zero_debug(f"The following module parameters are currently thawed: {[n for n in curr_thawed]}")
-        return thawed_p_names, curr_thawed
+        assert isinstance(self.ft_schedule, Dict)
+        opt = self.pl_module.trainer.optimizers[0]
+        sched = self.ft_schedule
+        no_grad_cnt = len([p for pg in opt.param_groups for p in pg["params"] if not p.requires_grad])
+        req_grad_opt = len([p for pg in opt.param_groups for p in pg["params"] if p.requires_grad])
+        init_ft_cnt = len(self.strategy_adapter.fts_optim_view(sched[0]["params"]))
+        total_ft_cnt = len([p for phase in sched for p in self.strategy_adapter.fts_optim_view(sched[phase]["params"])])
+        expected_grad_params = req_grad_opt == init_ft_cnt
+        return no_grad_cnt, init_ft_cnt, total_ft_cnt, req_grad_opt, expected_grad_params
 
-    @staticmethod
-    def _validate_opt_init(optimizer: Optimizer, ft_schedule: Dict) -> None:
+    def _validate_opt_init(self) -> None:
         """Validate the user-initialized optimizer state (necessary for fine-tuning phase 0) and warn user if
         appropriate.
 
@@ -1340,11 +1412,7 @@ class ScheduleImplMixin(ABC):
             optimizer (Optimizer): The optimizer initialized.
             ft_schedule (Dict): The fine-tuning schedule to be inspected vis-a-vis the optimizer state.
         """
-        no_grad_cnt = len([p for pg in optimizer.param_groups for p in pg["params"] if not p.requires_grad])
-        init_ft_cnt = len(ft_schedule[0]["params"])
-        total_ft_cnt = len([p for phase in ft_schedule for p in ft_schedule[phase]["params"]])
-        req_grad_opt = len([p for pg in optimizer.param_groups for p in pg["params"] if p.requires_grad])
-        expected_grad_params = req_grad_opt == init_ft_cnt
+        no_grad_cnt, init_ft_cnt, total_ft_cnt, req_grad_opt, expected_grad_params = self._inspect_fts_opt_state()
         if no_grad_cnt > 0 or not expected_grad_params:
             warn_msg = (
                 f"FinetuningScheduler configured the provided model to have {init_ft_cnt} trainable parameters"
@@ -1381,8 +1449,8 @@ class CallbackDepMixin(ABC):
     """Functionality for validating/managing callback dependencies."""
 
     def __init__(self, callback_dep_parents: Dict = CALLBACK_DEP_PARENTS) -> None:
-        """Initialize the user-provided callback dependency validation in accordance with the user-provided module
-        configuration.
+        """Arguments used to initialize the user-provided callback dependency validation in accordance with the
+        user-provided module configuration:
 
         Args:
             callback_dep_parents (Dict, optional): The parent classes of all user-provided callbacks in the module that
@@ -1431,6 +1499,8 @@ class CallbackDepMixin(ABC):
                 if dep_callback_cnts[k] > 1:
                     break
         for k, v in dep_callback_cnts.items():
+            # this block is only required for any non-stateful callback dependencies as multiple stateful callback
+            # dependencies will be prevented in on_train_init
             if v > 1:
                 dep_callback_errs.append(f"Use of multiple {k} {err_suffix}")
         if dep_callback_errs:
@@ -1452,6 +1522,25 @@ class CallbackDepMixin(ABC):
         other_callbacks = [c for c in callbacks if not isinstance(c, target_callback)]
         return other_callbacks + target_callbacks
 
+    def _callback_dep_setup(self, trainer: "pl.Trainer", pl_module: "pl.LightningModule", stage: str) -> None:
+        """Ensures all :class:`~finetuning_scheduler.fts.FinetuningScheduler` callback dependencies are met, adding
+        and configuring them if necessary.
+
+        Args:
+            trainer (:external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer`): The
+                :external+pl:class:`~pytorch_lightning.trainer.trainer.Trainer` object
+            pl_module (:external+pl:class:`~pytorch_lightning.core.module.LightningModule`): The
+                :external+pl:class:`~pytorch_lightning.core.module.LightningModule` object
+            stage: The ``RunningStage.{SANITY_CHECKING,TRAINING,VALIDATING}``. Defaults to None.
+        """
+        trainer.callbacks, added_es_fts, added_ckpt_fts = self._configure_callback_deps(trainer)
+        # if we added callbacks for the user after the setup hooks loop was initiated from trainer, we'll need to
+        # explicitly call the setup hooks for those added callbacks
+        if added_ckpt_fts:
+            trainer.checkpoint_callback.setup(trainer, pl_module, stage)  # type: ignore[union-attr]
+        if added_es_fts:
+            trainer.early_stopping_callback.setup(trainer, pl_module, stage)  # type: ignore[union-attr]
+
     def _configure_callback_deps(self, trainer: "pl.Trainer") -> Tuple[List[Callback], bool, bool]:
         """Ensures FTSCheckpoint and :external+pl:class:`~pytorch_lightning.callbacks.early_stopping.EarlyStopping`
         callbacks are present and configured, removing any.
