@@ -189,7 +189,7 @@ class RteBoolqModule(pl.LightningModule):
     ):
         """In this example, this :class:`~pytorch_lightning.core.module.LightningModule` is initialized by composing
         the ./config/fts_defaults.yaml default configuration with various scheduled fine-tuning yaml configurations
-        via the :class:`~pytorch_lightning.utilities.cli.LightningCLI` but it can be used like any other
+        via the :class:`~pytorch_lightning.cli.LightningCLI` but it can be used like any other
         :class:`~pytorch_lightning.core.module.LightningModule` as well.
 
         Args:
@@ -316,7 +316,7 @@ class RteBoolqModule(pl.LightningModule):
 
 
 class CustLightningCLI(LightningCLI):
-    """Customize the :class:`~pytorch_lightning.utilities.cli.LightningCLI` to ensure the
+    """Customize the :class:`~pytorch_lightning.cli.LightningCLI` to ensure the
     :class:`~pytorch_lighting.core.LightningDataModule` and :class:`~pytorch_lightning.core.module.LightningModule`
     use the same Hugging Face model, SuperGLUE task and custom logging tag."""
 
